@@ -9,6 +9,7 @@ from Cheese.httpClientErrors import *
 from Cheese.resourceManager import ResMan
 from Cheese.appSettings import Settings
 from Cheese.Logger import Logger
+from Cheese.fileHeaders import FileHeaders
 
 class CheeseController:
     """
@@ -49,7 +50,7 @@ class CheeseController:
         return headers
 
     @staticmethod
-    def modulesToJsonArray(modules) -> list:
+    def modulesToJsonArray(modules, allData=True, upperKeys=True) -> list:
         """
         return json array from list of modules
 
@@ -57,7 +58,7 @@ class CheeseController:
         """        
         jsonArray = []
         for m in modules:
-            jsonArray.append(m.toJson())
+            jsonArray.append(m.toJson(allData, upperKeys))
         return jsonArray
 
     @staticmethod
@@ -258,6 +259,9 @@ class CheeseController:
 
             CheeseController.sendResponse(server, (bytes(data, "utf-8"), 200, {"Content-type": header}))
         else:
+            try: header = FileHeaders.getHeader(file)
+            except: Logger.info(f"Suffix for {file} not found")
+
             with open(f"{file}", "rb") as f:
                 CheeseController.sendResponse(server, (f.read(), 200, {"Content-type": header}))
 
