@@ -1,6 +1,6 @@
 #cheese
 
-from datetime import datetime
+import datetime
 import inspect
 import re
 
@@ -8,6 +8,7 @@ from Cheese.metadata import Metadata
 from Cheese.cheeseModel import CheeseModel
 from Cheese.resourceManager import ResMan
 from Cheese.database import Database
+from Cheese.Logger import Logger
 
 class CheeseRepository:
     """
@@ -15,9 +16,11 @@ class CheeseRepository:
     """
 
     testing = False
+    __commitSql = ""
+    __autoCommit = True
 
     @classmethod
-    def model(cls) -> CheeseModel:
+    def model(cls, addId=0) -> CheeseModel:
         """
         return ```CheeseModel``` with ```Primary key```, ```modelName``` and ```scheme```
         """
@@ -28,7 +31,7 @@ class CheeseRepository:
         model = CheeseModel(modelName, scheme)
         for sch in scheme:
             if (sch == "id"):
-                setattr(model, sch, cls.findNewId())
+                setattr(model, sch, cls.findNewId()+addId)
             else:
                 setattr(model, sch, "")
         return model
@@ -235,12 +238,37 @@ class CheeseRepository:
 
     @staticmethod
     def commitType(preparedSql):
-        db = Database()
-        db.commit(preparedSql)
-        db.done()
+        if (CheeseRepository.__autoCommit):
+            db = Database()
+            db.commit(preparedSql)
+            db.done()
+        else:
+            if (not preparedSql.endswith(";")):
+                preparedSql += ";"
+            preparedSql += "\n"
+            CheeseRepository.__commitSql += preparedSql
 
         return True
 
+    @staticmethod
+    def commit():
+        if (CheeseRepository.__commitSql != ""):
+            db = Database()
+            db.commit(CheeseRepository.__commitSql)
+            db.done()
+            CheeseRepository.__commitSql = ""
+            Logger.okGreen("Commited")
+        else:
+            Logger.warning("Nothing to commit")
+
+    @staticmethod
+    def disableAutocommit():
+        CheeseRepository.__autoCommit = False
+    
+    @staticmethod
+    def enableAutocommit():
+        CheeseRepository.__autoCommit = True
+
     @staticmethod
     def toModel(repository, data):
         if (len(data) == 0):
@@ -313,8 +341,10 @@ class CheeseRepository:
                 return str(arg)
         elif (type(arg) is list):
             return "(" + ",".join(CheeseRepository.getTypeOf(arg)) + ")"
-        elif (type(arg) is datetime):
-            return "'" + datetime.strftime(arg, "%Y-%m-%dT%H:%M:%S") + "'"
+        elif (type(arg) is datetime.datetime):
+            return "'" + datetime.datetime.strftime(arg, "%Y-%m-%dT%H:%M:%S") + "'"
+        elif (type(arg) is datetime.date):
+            return "'" + datetime.datetime.strftime(arg, "%Y-%m-%d") + "'"
         elif (isinstance(arg, CheeseModel)):
             ret = []
             for var in variables:
